==> robodoc_4.0.18.orig.tar.gz: robodoc-4.0.18/Source/html_generator.h <==
#ifndef ROBODOC_HTML_GENERATOR_H
#define ROBODOC_HTML_GENERATOR_H

#include "headers.h"
#include "document.h"

#define MAX_SECTION_DEPTH 7

void                RB_HTML_Generate_Label( FILE * dest_doc, char *name );
void                RB_HTML_Generate_Item_Begin( FILE * dest_doc );
void                RB_HTML_Generate_Item_End( FILE * dest_doc );
void                RB_HTML_Generate_TOC_2( FILE * dest_doc,
                                            struct RB_header **headers,
                                            int count, struct RB_Part *owner,
                                            char *dest_name );
void                RB_HTML_Generate_BeginSection( FILE * dest_doc, int depth,
                                                   char *name );
void                RB_HTML_Generate_EndSection( FILE * dest_doc, int depth,
                                                 char *name );
char               *RB_HTML_Get_Default_Extension( void );
void                RB_HTML_Generate_Doc_Start( FILE * dest_doc,
                                                char *src_name, char *name,
                                                char toc, char *dest_name,
                                                char *charset );
void                RB_HTML_Generate_Doc_End( FILE * dest_doc, char *name );
void                RB_HTML_Generate_Header_Start( FILE * dest_doc,
                                                   struct RB_header
                                                   *cur_header );
void                RB_HTML_Generate_Header_End( FILE * dest_doc,
                                                 struct RB_header
                                                 *cur_header );

void RB_HTML_Generate_Index( struct RB_Document *document );

void
RB_HTML_Generate_Index_Table( 
        FILE * dest, char *dest_name,
        struct RB_HeaderType* type,
        char *title );

void                RB_HTML_Generate_Empty_Item( FILE * dest );
void                RB_HTML_Generate_Link( FILE * dest, char *dest_name,
                                           char *filename, char *labelname,
                                           char *linkname, int in_fold );
void                RB_HTML_Generate_Char( FILE * dest_doc, int c );
void                RB_HTML_Generate_Item_Name( FILE * dest_doc, char *name );
char               *RB_HTML_RelativeAddress( char *thisname, char *thatname );
int                 RB_HTML_Generate_Extra( FILE * dest_doc, int item_type,
                                            char *cur_char );
void                RB_HTML_Generate_False_Link( FILE * dest_doc,
                                                 char *name );
void                RB_Create_CSS( struct RB_Document *document );
void                RB_InsertCSS( FILE * dest_doc, char *filename );

#endif /* ROBODOC_HTML_GENERATOR_H */

==> robodoc-4.99.6.tar.gz: robodoc-4.99.6/Source/html_generator.h <==
#ifndef ROBODOC_HTML_GENERATOR_H
#define ROBODOC_HTML_GENERATOR_H

#include "headers.h"
#include "items.h"
#include "document.h"

#define MAX_SECTION_DEPTH 7

void                RB_HTML_Generate_Label( FILE * dest_doc, char *name );
void                RB_HTML_Generate_Item_Begin( FILE * dest_doc, char *name );
void                RB_HTML_Generate_Item_End( FILE * dest_doc, char *name );
void                RB_HTML_Generate_TOC_2( FILE * dest_doc,
                                            struct RB_header **headers,
                                            int count, struct RB_Part *owner,
                                            char *dest_name );
void                RB_HTML_Generate_BeginSection( FILE * dest_doc, int depth,
                                                   char *name );
void                RB_HTML_Generate_EndSection( FILE * dest_doc, int depth,
                                                 char *name );
char               *RB_HTML_Get_Default_Extension( void );
void                RB_HTML_Generate_Doc_Start( FILE * dest_doc,
                                                char *src_name, char *name,
                                                char toc, char *dest_name,
                                                char *charset );
void                RB_HTML_Generate_Doc_End( FILE * dest_doc, char *name );
void                RB_HTML_Generate_Header_Start( FILE * dest_doc,
                                                   struct RB_header
                                                   *cur_header );
void                RB_HTML_Generate_Header_End( FILE * dest_doc,
                                                 struct RB_header
                                                 *cur_header );

void RB_HTML_Generate_Index( struct RB_Document *document );

void
RB_HTML_Generate_Index_Table( 
        FILE * dest, char *dest_name,
        struct RB_HeaderType* type,
        char *title );

void                RB_HTML_Generate_Empty_Item( FILE * dest );
void                RB_HTML_Generate_Link( FILE * dest, char *dest_name,
                                           char *filename, char *labelname,
                                           char *linkname, int in_fold );
void                RB_HTML_Generate_Char( FILE * dest_doc, int c );
void                RB_HTML_Generate_Item_Name( FILE * dest_doc, char *name );
char               *RB_HTML_RelativeAddress( char *thisname, char *thatname );

int                 RB_HTML_Generate_Extra( FILE * dest_doc, enum ItemType item_type, char *cur_char );

void                RB_HTML_Generate_False_Link( FILE * dest_doc,
                                                 char *name );
void                RB_Create_CSS( struct RB_Document *document );
void                RB_InsertCSS( FILE * dest_doc, char *filename );
void                RB_HTML_Generate_Nav_Bar( struct RB_Document* document, 
                        FILE* current_doc, struct RB_header *current_header );


void HTML_Generate_Begin_Paragraph( FILE* dest_doc );
void HTML_Generate_End_Paragraph( FILE* dest_doc );

void HTML_Generate_Begin_Preformatted( FILE* dest_doc );
void HTML_Generate_End_Preformatted( FILE* dest_doc );

void HTML_Generate_Begin_List( FILE* dest_doc );
void HTML_Generate_End_List( FILE* dest_doc );
void HTML_Generate_Begin_List_Item( FILE* dest_doc );
void HTML_Generate_End_List_Item( FILE* dest_doc );

#endif /* ROBODOC_HTML_GENERATOR_H */
